<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
    xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:dk="kelis.fr:dokiel"
    xmlns:hdoc="http://www.utc.fr/ics/hdoc/xhtml" exclude-result-prefixes="xs" version="2.0">
    <xsl:output method="xml" indent="yes"/>
    <!-- PAPER GUIDE -->
    <xsl:template match="hdoc:html">

        <xsl:element name="sc:item">
            <xsl:element name="dk:guidePRoot">


                <xsl:apply-templates select="hdoc:head" mode="GuideSpecial"/>
                <xsl:element name="sp:guide">
                    <xsl:attribute name="sc:refUri">
                        <!--Generic Name -->
                        <xsl:text>&amp;/GuideUtilisateur.scen</xsl:text>
                    </xsl:attribute>
                    <xsl:result-document href="&amp;/GuideUtilisateur.scen">
                        <xsl:element name="sc:item">
                            <xsl:element name="dk:userGuide">
                                <xsl:apply-templates select="hdoc:head"/>
                                <xsl:apply-templates select="hdoc:body"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:result-document>
                </xsl:element>
            </xsl:element>
        </xsl:element>

        <!-- USER GUIDE -->
    </xsl:template>
    <xsl:template match="hdoc:head" mode="GuideSpecial">
        <xsl:element name="dk:guidePRootM">
            <xsl:element name="sp:longTitle">
                <xsl:element name="dk:textSimple">
                    <xsl:element name="sc:para">
                        <xsl:attribute name="xml:space">preserve</xsl:attribute>
                        <xsl:attribute name="sc:id">t2</xsl:attribute>
                        <xsl:value-of select="hdoc:title"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>
            <xsl:element name="sp:info">
                <xsl:element name="dk:rootM">
                    <xsl:element name="sp:copyright">
                        <xsl:value-of select="hdoc:meta[@name='author']/@content"/>
                    </xsl:element>
                </xsl:element>
            </xsl:element>

        </xsl:element>
    </xsl:template>

    <!-- HDOC HEADER -->
    <xsl:template match="hdoc:head">

        <xsl:element name="dk:headTitle">
            <xsl:element name="sp:sTitle">
                <xsl:value-of select="hdoc:title"/>
            </xsl:element>
        </xsl:element>

    </xsl:template>

    <!-- HDOC BODY -->
    <xsl:template match="hdoc:body">
        <xsl:apply-templates select="hdoc:section"/>
    </xsl:template>

    <!-- INTRODUCTION -->
    <xsl:template match="hdoc:section[@data-hdoc-type='introduction']">
        <xsl:element name="sp:intro">
            <xsl:call-template name="intro_conclu"/>
        </xsl:element>
    </xsl:template>

    <!-- CLASSIC SECTION -->
    <xsl:template match="hdoc:section">
        <!-- EXTERNALIZE , thanks to the function count, that allow to name the files with a unique id in the entire document hdoc-->
        <xsl:element name="sp:subSection">
            <xsl:attribute name="sc:refUri">
                <xsl:text>sect</xsl:text>
                <xsl:value-of
                    select="count(preceding::hdoc:section)+count(ancestor::hdoc:section)+1"/>
                <xsl:text>.scen</xsl:text>
            </xsl:attribute>
        </xsl:element>
        <xsl:result-document
            href="&amp;/sect{count(preceding::hdoc:section)+count(ancestor::hdoc:section)+1}.scen">
            <xsl:element name="sc:item">
                <xsl:element name="dk:section">
                    <xsl:element name="dk:headTitle">
                        <xsl:element name="sp:sTitle">
                            <xsl:value-of select="hdoc:header/hdoc:h1"/>
                        </xsl:element>
                    </xsl:element>
                    <xsl:if test="hdoc:div">
                        <xsl:element name="sp:content">
                            <xsl:element name="dk:content">
                                <xsl:apply-templates select="hdoc:div"/>
                            </xsl:element>
                        </xsl:element>
                    </xsl:if>
                    <xsl:apply-templates select="hdoc:section"/>
                </xsl:element>
            </xsl:element>
        </xsl:result-document>
    </xsl:template>

    <!-- CONCLUSION -->
    <xsl:template match="hdoc:section[@data-hdoc-type='conclusion']">
        <xsl:element name="sp:conclu">
            <xsl:call-template name="intro_conclu"/>
        </xsl:element>
    </xsl:template>

    <!-- INTRO & CONCLU -->
    <xsl:template name="intro_conclu">
        <xsl:element name="dk:optHTitle">
            <xsl:element name="sp:sTitle">
                <xsl:value-of select="hdoc:header/hdoc:h1"/>
            </xsl:element>
            <!-- Traiter aussi les titres riches ?? Textes riches = plusieurs paragraphes et pas qu'une phrase/ligne -->

        </xsl:element>
        <xsl:element name="dk:comment">
            <xsl:apply-templates select="hdoc:div"/>
        </xsl:element>
    </xsl:template>

    <!-- DIV HANDLING -->
    <!-- obvious formats -->
    <xsl:template match="hdoc:div">
        <xsl:element name="sp:infobloc">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="hdoc:div[@data-hdoc-type='example']">
        <xsl:element name="sp:example">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="hdoc:div[@data-hdoc-type='remark']">
        <xsl:element name="sp:note">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="hdoc:div[@data-hdoc-type='warning']">
        <xsl:element name="sp:warning">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="hdoc:div[@data-hdoc-type='complement']">
        <xsl:element name="sp:complement">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>
    <!-- formats for whom a technological choice is needed -->
    <!-- Authored block is not managed  -->
    <xsl:template match="hdoc:div[@data-hdoc-type='debate']">
        <xsl:element name="sp:legal">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="hdoc:div[@data-hdoc-type='definition']">
        <xsl:element name="sp:advice">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>
    <xsl:template match="hdoc:div[@data-hdoc-type='emphasis']">
        <xsl:element name="sp:warning">
            <xsl:call-template name="contenuBloc"/>
        </xsl:element>
    </xsl:template>

    <!-- DIV CONTENT HANDLING (Same format for every bloc) -->
    <xsl:template name="contenuBloc">
        <xsl:element name="dk:blocTi">
            <xsl:if test="hdoc:h6">
                <xsl:element name="sp:rTitle">
                    <xsl:element name="dk:richTitle">
                        <xsl:element name="sc:para">
                            <xsl:attribute name="xml:space">preserve</xsl:attribute>
                            <!-- gestion des id scenari ???-->
                            <!-- <xsl:attribute name="sc:id">????</xsl:attribute> -->
                            <xsl:value-of select="hdoc:h6"/>
                        </xsl:element>
                    </xsl:element>
                </xsl:element>
            </xsl:if>
        </xsl:element>
        <xsl:element name="dk:flowAll">
            <xsl:element name="sp:txt">
                <xsl:element name="dk:text">
                    <!-- to avoid the h6 tag -->
                    <xsl:apply-templates select="*[name()!='h6']"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
    </xsl:template>

    <!-- TEXT HANDLING -->
    <xsl:template match="hdoc:p">
        <xsl:element name="sc:para">
            <xsl:attribute name="xml:space">preserve</xsl:attribute>
            <!-- gestion des id scenari ???-->
            <!-- <xsl:attribute name="sc:id">????</xsl:attribute> -->
            <xsl:value-of select="."/>
        </xsl:element>

    </xsl:template>
    <!-- JPEG HANDLING -->
    <xsl:template match="hdoc:img"> 
        <xsl:element name="sc:extBlock">
            <xsl:attribute name="role">fig</xsl:attribute>
            <xsl:attribute name="sc:refUri"><xsl:value-of select="tokenize(@src,'/')[last()]"/></xsl:attribute>
            
        </xsl:element>
    </xsl:template>
    <!-- END -->
</xsl:stylesheet>
