<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
    xmlns:of="scpf.org:office"
    xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
    xmlns:h="http://www.utc.fr/ics/hdoc/xhtml">
    <xsl:output method="xml" indent="yes"/>
    <xsl:template match="h:html">
        <xsl:processing-instruction name="oxygen">
            RNGSchema="exportRngOptim/of_paper.rng" type="xml" 
        </xsl:processing-instruction>
        <sc:item xmlns:sc="http://www.utc.fr/ics/scenari/v3/core">
            <of:paper xmlns:of="scpf.org:office" xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core">
                <xsl:apply-templates/>
            </of:paper>
        </sc:item>
    </xsl:template>
    
    <xsl:template match="h:head">
        <of:paperM>
            <xsl:apply-templates select="h:title"/>
            <sp:commonMeta>
                <of:commonM>
                    <sp:copyright>
                        <xsl:value-of select="h:meta[@name='author']/@content"/>
                        <xsl:if test="h:meta[@name='author'] and h:meta[@name='rights']"> - </xsl:if>
                        <xsl:value-of select="h:meta[@name='rights']/@content"/>
                    </sp:copyright>
                </of:commonM>
            </sp:commonMeta>
        </of:paperM>
        <xsl:if test="h:meta[@name='description'] or h:meta[@name='keywords']">
            <sp:pre>
                <of:section>
                    <of:sectionM>
                        <sp:title>Méta-données</sp:title>
                    </of:sectionM>
                    <sp:content>
                        <of:fragment>
                            <xsl:apply-templates select="h:meta[@name='description']"/>
                            <xsl:apply-templates select="h:meta[@name='keywords']"/>
                        </of:fragment>
                    </sp:content>
                </of:section>
            </sp:pre>
        </xsl:if>
    </xsl:template>

    <xsl:template match="h:meta[@name='description'] | h:meta[@name='keywords']">
        <sp:info>
            <of:block>
                <of:blockM>
                    <sp:title>
                        <xsl:if test="@name='description'">Description</xsl:if>
                        <xsl:if test="@name='keywords'">Mots-clés</xsl:if>
                    </sp:title>         
                </of:blockM>
                <sp:co>
                    <of:flow>
                        <sp:txt>
                            <of:txt>
                                <sc:para xml:space="preserve">
                                    <xsl:value-of select="@content"/>
                                </sc:para>
                            </of:txt>
                        </sp:txt>
                    </of:flow>
                </sp:co>
            </of:block>
        </sp:info>
    </xsl:template>
    
    <xsl:template match="h:title | h:h1 | h:h6">
        <sp:title><xsl:value-of select="."/></sp:title>
    </xsl:template>
    
    <xsl:template match="h:body">
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="h:body/h:section">
        <sp:chap>
            <xsl:call-template name="sec-body"/>
        </sp:chap>
    </xsl:template>
    
    <xsl:template match="h:section">
        <sp:sec>
            <xsl:call-template name="sec-body"/>
        </sp:sec>
    </xsl:template>
    
    <xsl:template name="sec-body">
        <of:section>
            <xsl:apply-templates select="h:header"/>
            <xsl:if test="./h:div">
                <sp:content>
                    <of:fragment>
                        <xsl:apply-templates select="h:div"/>
                    </of:fragment>
                </sp:content>
            </xsl:if>
            <xsl:apply-templates select="h:section"/>
        </of:section>
    </xsl:template>

    <xsl:template match="h:header">
        <of:sectionM>
            <xsl:apply-templates/>
        </of:sectionM>
    </xsl:template>
    
    <xsl:template match="h:div[@data-hdoc-type]">
        <xsl:comment>
            <xsl:if test="@data-hdoc-type='author'">Auteur : <xsl:value-of select="."/></xsl:if>
            <xsl:if test="@data-hdoc-type='date'">Date : <xsl:value-of select="."/></xsl:if>
            <xsl:if test="@data-hdoc-type='rights'">Droits : <xsl:value-of select="."/></xsl:if>
        </xsl:comment>
    </xsl:template>
    
    <xsl:template match="h:div">
        <sp:info>
            <xsl:call-template name="div-body"/>
        </sp:info>
    </xsl:template>
    
    <xsl:template match="h:div[@data-hdoc-type='emphasis']">
        <sp:emphasis>
            <of:filter/>
            <xsl:call-template name="div-body"/>
        </sp:emphasis>
    </xsl:template>
    
    <xsl:template name="div-body">
        <of:block>
            <of:blockM>
                <xsl:apply-templates select="h:h6"/>
            </of:blockM>
            <sp:co>
                <of:flow>
                    <sp:txt>
                        <of:txt>
                            <xsl:apply-templates select="*[not(self::h:h6)]"/>
                        </of:txt>
                    </sp:txt>
                </of:flow>
            </sp:co>
        </of:block>
    </xsl:template>
    
    <xsl:template match="h:p">
        <sc:para xml:space="preserve">
            <xsl:apply-templates/>
        </sc:para>
    </xsl:template>
    
    <xsl:template match="h:ul">
        <sc:itemizedList>
            <xsl:apply-templates/>
        </sc:itemizedList>
    </xsl:template>
    
    <xsl:template match="h:ol">
        <sc:orderedList>
            <xsl:apply-templates/>
        </sc:orderedList>
    </xsl:template>
    
    <xsl:template match="h:li">
        <sc:listItem>
            <xsl:apply-templates/>
        </sc:listItem>
    </xsl:template>
    
    <xsl:template match="h:a">
        <sc:uLink role="url" url="{@href}">
            <xsl:apply-templates/>
        </sc:uLink>
    </xsl:template>
    
    <xsl:template match="h:em">
        <sc:inlineStyle role="emphasis">
            <xsl:apply-templates/>
        </sc:inlineStyle>
    </xsl:template>
    
    <xsl:template match="h:i">
        <sc:inlineStyle role="special">
            <xsl:apply-templates/>
        </sc:inlineStyle>
    </xsl:template>
    
    <xsl:template match="h:table">
        <sc:table role="">
            <xsl:apply-templates select="h:caption"/>
            <xsl:for-each select="h:tr[1]/h:td">
                <sc:column width="20"/>
            </xsl:for-each>
            <xsl:apply-templates select="h:tr"/>
        </sc:table>
    </xsl:template>
    
    <xsl:template match="h:span">
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="h:caption">
        <sc:caption xml:space="preserve">
            <xsl:value-of select="."/>
        </sc:caption>
    </xsl:template>
    
    <xsl:template match="h:tr">
        <sc:row>
            <xsl:apply-templates/>
        </sc:row>
    </xsl:template>

    <xsl:template match="h:td">
        <sc:cell>
            <xsl:apply-templates/>
        </sc:cell>
    </xsl:template>

</xsl:stylesheet>